"""
A collection of test problems for black-box optimization.

"""

from optproblems.base import *
from optproblems.binary import *
from optproblems.mpm import *
from optproblems.multiobjective import *
from optproblems.wfg import *
from optproblems.zdt import *

__version__ = "0.2"
